@@ -1,6 +1,6 @@
 package Pcore::Handle::Firebird;
 
-use Pcore qw[-class];
+use Pcore -class;
 use DBD::Firebird;
 
 with qw[Pcore::DBD];
